==> schema_widget-1.0.0.tar.gz: lib/parser/type/underline_tab_indicator_schema_parser.dart <==
// Copyright (c) 2020 Legytma Soluções Inteligentes (https://legytma.com.br).
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//       http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

import 'package:flutter/material.dart';
import 'package:json_schema/json_schema.dart';

import '../../schema_widget.dart';

/// Schema parser from [Map<String, dynamic>] to [UnderlineTabIndicator]
///
/// Created by Windol <windol@legytma.com.br> at 30/04/2020.
/// Copyright (c) 2020 Legytma Soluções Inteligentes (https://legytma.com.br). All rights reserved.
@SchemaParser("UnderlineTabIndicator",
    "https://schema.legytma.com.br/2.0.0/schema/underline_tab_indicator.schema.json")
class UnderlineTabIndicatorSchemaParser extends TypeSchemaParser<
    UnderlineTabIndicator, Map<String, dynamic>, UnderlineTabIndicator> {
  /// Create instance of parser using [JsonSchema] to validate values.
  UnderlineTabIndicatorSchemaParser([JsonSchema jsonSchema])
      : super(jsonSchema);

  @override
  UnderlineTabIndicator builder(
      BuildContext buildContext, Map<String, dynamic> value,
      [UnderlineTabIndicator defaultValue]) {
    return UnderlineTabIndicator(
      borderSide: SchemaWidget.parse<BorderSide>(
          buildContext,
          value['borderSide'],
          const BorderSide(width: 2.0, color: Colors.white)),
      insets: SchemaWidget.parse<EdgeInsetsGeometry>(
          buildContext, value['insets'], EdgeInsets.zero),
    );
  }
}

==> schema_widget-1.0.0-5.tar.gz: lib/parser/type/underline_tab_indicator_schema_parser.dart <==
// Copyright (c) 2020 Legytma Soluções Inteligentes (https://legytma.com.br).
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//       http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

import 'package:flutter/material.dart';
import 'package:json_schema/json_schema.dart';

import '../../schema_widget.dart';

/// Schema parser from [Map<String, dynamic>] to [UnderlineTabIndicator]
///
/// Created by Windol <windol@legytma.com.br> at 30/04/2020.
/// Copyright (c) 2020 Legytma Soluções Inteligentes (https://legytma.com.br). All rights reserved.
@SchemaParser("UnderlineTabIndicator",
    "https://schema.legytma.com.br/2.0.0/schema/underline_tab_indicator.schema.json")
class UnderlineTabIndicatorSchemaParser extends TypeSchemaParser<
    UnderlineTabIndicator, Map<String, dynamic>, UnderlineTabIndicator> {
  /// Create instance of parser using [JsonSchema] to validate values.
  UnderlineTabIndicatorSchemaParser(JsonSchema jsonSchema) : super(jsonSchema);

  @override
  UnderlineTabIndicator builder(
      BuildContext buildContext, Map<String, dynamic> value,
      [UnderlineTabIndicator defaultValue]) {
    return UnderlineTabIndicator(
      borderSide: SchemaWidget.parse<BorderSide>(
          buildContext,
          value['borderSide'],
          const BorderSide(width: 2.0, color: Colors.white)),
      insets: SchemaWidget.parse<EdgeInsetsGeometry>(
          buildContext, value['insets'], EdgeInsets.zero),
    );
  }
}
